/**
 * Retrieve an URL synchronously. Note that this is synchronous, that is, it
 * will block (stall the browser!) until it's done downloading the entire
 * document.
 */
function getURL(url, username, password, asXML)
{
    const request = new XMLHttpRequest();
    
    // Retrieve page
    request.open("GET", url, false);
    // Basic authentication should be used
    if(username.length > 0)
    {
        var text = username + ":" + password;
        text = encodeBase64(text);
        request.setRequestHeader("Authorization", "Basic " + text);
    }
    request.send(null);
    
    if (request.readyState == 4 && request.status == 200)
    {
    	if(asXML) return request.responseXML;    	
    	else return request.responseText;
    }
    else throw("Unable to get URL '" + url + "' status code " + request.status);
}

/**
 * Retrieve an URL asynchronously.
 * The callback function given as a parameter will be called when the URL has been
 * loaded successfully.
 */
function asyncGetURL(url, username, password, asXML, callback)
{
    request = new XMLHttpRequest();
    // Open an asynchronous request
    request.open("GET", url, true, username, password);
    request.onreadystatechange = function() {
        // 4 is the "completed" state
        if(request.readyState==4) {
            switch(request.status) {
                case 401:
                    alert("Del.icio.us couldn't authorize this operation. Please check the used account's username and password and retry.");
                    break;
                case 200:
                    // HTTP "OK". Successfully posted.
                    if(callback) {
                        if(asXML) {
                            callback(request.responseXML);
                        } else {
                            callback(request.responseText);
                        }
                    }
                    break;
                default:
                    alert("Operation failed. HTTP status "+request.statusText+"("+request.status+").");
                    break;
            }
        }
    };
    request.send(null);
}
